Crate converter_buddy

Crate converter_buddy 

Modules

config
converter
decoder
format
Contains the formats and their info used by the converter.
io

Macros

define_converter
Macro used to define a dynamic converter. To achieve this ConversionStrategy is implemented by relegating the actual conversion to its implementation using the actual format config structure as a generic. Furthermore, ConversionInfo traits is automatically implemented to provide a handy function in a dynamic environment. The first element is the converter and then a comma separated supported formats have to be provided.
impl_common_image_conversions